# colrev.ref_check

Checks the quality of reference metadata

## Installation

```bash
colrev install colrev.ref_check
```

## Usage

`colrev.ref_check` can be added as a data endpoint. It ensures that records are only set to `rev_synthesized` if there are no remaining defects in the record metadata.

## License

This project is licensed under the MIT License - see the [LICENSE](LICENSE) file for details.
